@@ -11,13 +11,11 @@ module Interpreter (
 -- exported for testing
 , ghcInfo
 , haveInterpreterKey
+, filterExpression
 ) where
 
 import           System.Process
 import           System.Directory (getPermissions, executable)
-#if __GLASGOW_HASKELL__ < 710
-import           Control.Applicative
-#endif
 import           Control.Monad
 import           Control.Exception hiding (handle)
 import           Data.Char
@@ -46,6 +44,7 @@ interpreterSupported = do
 -- Example:
 --
 -- >>> withInterpreter [] $ \i -> eval i "23 + 42"
+-- ...
 -- "65\n"
 withInterpreter
   :: [String]               -- ^ List of flags, passed to GHC
@@ -55,6 +54,7 @@ withInterpreter flags action = do
   let
     args = flags ++ [
         "--interactive"
+      , xTemplateHaskell
 #if __GLASGOW_HASKELL__ >= 802
       , "-fdiagnostics-color=never"
       , "-fno-diagnostics-show-caret"
@@ -62,6 +62,9 @@ withInterpreter flags action = do
       ]
   bracket (new defaultConfig{configGhci = ghc} args) close action
 
+xTemplateHaskell :: String
+xTemplateHaskell = "-XTemplateHaskell"
+
 -- | Evaluate an expression; return a Left value on exceptions.
 --
 -- An exception may e.g. be caused on unterminated multiline expressions.
@@ -75,11 +78,17 @@ filterExpression :: String -> Either String String
 filterExpression e =
   case lines e of
     [] -> Right e
-    l  -> if firstLine == ":{" && lastLine /= ":}" then fail_ else Right e
+    l  -> if firstLine == ":{" && lastLine /= ":}" then err else Right (filterXTemplateHaskell e)
       where
         firstLine = strip $ head l
         lastLine  = strip $ last l
-        fail_ = Left "unterminated multiline command"
+        err = Left "unterminated multi-line command"
   where
     strip :: String -> String
     strip = dropWhile isSpace . reverse . dropWhile isSpace . reverse
+
+filterXTemplateHaskell :: String -> String
+filterXTemplateHaskell input = case words input of
+  [":set", setting] | setting == xTemplateHaskell -> ""
+  ":set" : xs | xTemplateHaskell `elem` xs -> unwords $ ":set" : filter (/= xTemplateHaskell) xs
+  _ -> input
